//
//  ViewController.m
//  JMWireless
//
//  Created by admin on 16/11/22.
//  Copyright © 2016年 unknown. All rights reserved.
//

#import "SVProgressHUD.h"
#import "WQBleSettings.h"
#import "WQConstant.h"
#import "JMBle.h"

@interface WQBleSettings ()
<
    UITableViewDelegate,
    UITableViewDataSource
>
@property (nonatomic, weak) UITableView *tableView;
@property (nonatomic, copy) NSArray<CBPeripheral *> *devices;
@end

@implementation WQBleSettings
- (NSArray *)devices {
    if (_devices == nil) {
        _devices = [[NSArray alloc] init];
    }
    return _devices;
}

- (void)viewDidLoad {
    [super viewDidLoad];
    UITableView *tableView = [[UITableView alloc] initWithFrame:self.view.bounds
                                                          style:UITableViewStylePlain];
    [tableView registerClass:[UITableViewCell class]
      forCellReuseIdentifier:@"Cell"];
    tableView.delegate = self;
    tableView.dataSource = self;
    self.tableView = tableView;
    [self.view addSubview:self.tableView];
}

- (IBAction)searchClick:(id)sender {
    if (!SINGLETONBLE.isScanning) {
        [SINGLETONBLE performSelector:@selector(stopScan)
                           withObject:nil
                           afterDelay:3.f];
    }
    [SINGLETONBLE scanWithDiscover:^(NSError *error,
                                     CBPeripheral *peripheral,
                                     NSDictionary<NSString *,id> *advertisementData,
                                     NSNumber *RSSI) {
        if (error) {
            WQLogError(@"error: %@",error);
            [SVProgressHUD setMinimumDismissTimeInterval:2.f];
            [SVProgressHUD showErrorWithStatus:[NSString stringWithFormat:@"%@: %@",
                                                JMLocalized(@"Scan error"),error.localizedDescription]];
            return ;
        }
        if ([self.devices containsObject:peripheral]) {
            return;
        }
        NSMutableArray *devicesTmp = [[NSMutableArray alloc] initWithArray:self.devices];
        [devicesTmp addObject:peripheral];
        self.devices = devicesTmp;
        [self.tableView reloadData];
    }];
}

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView {
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView
 numberOfRowsInSection:(NSInteger)section {
    return self.devices.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView
         cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:@"Cell"
                                                            forIndexPath:indexPath];
    CBPeripheral *peripheral = self.devices[indexPath.row];
    cell.textLabel.text = peripheral.name;
    return cell;
}

- (void)tableView:(UITableView *)tableView
didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    CBPeripheral *peripheral = self.devices[indexPath.row];
    void (^complete)(NSError *error) = ^(NSError *error) {
        if (error) {
            WQLogError(@"error: %@",error);
            [SINGLETONBLE disconnect];
            [SVProgressHUD setMinimumDismissTimeInterval:2.f];
            [SVProgressHUD showErrorWithStatus:[NSString stringWithFormat:@"%@: %@",
                                                JMLocalized(@"Connect error"),error.localizedDescription]];
            return ;
        }
        WQLogMsg(@"连接成功 -- 类型: %d",SINGLETONBLE.printerType);
        [SINGLETONBLE disconnect];
        [SVProgressHUD setMinimumDismissTimeInterval:2.f];
        [SVProgressHUD showSuccessWithStatus:JMLocalized(@"The connection is available")];
    };
    UIAlertController *alert = [UIAlertController alertControllerWithTitle:JMLocalized(@"Bluetooth connection")
                                                                   message:JMLocalized(@"Connection test")
                                                            preferredStyle:UIAlertControllerStyleAlert];
    // 防丢单连接
    UIAlertAction *unLose = [UIAlertAction actionWithTitle:JMLocalized(@"Form Recovery connection test")
                                                     style:UIAlertActionStyleDefault
                                                   handler:^(UIAlertAction * _Nonnull action) {
                                                       [SVProgressHUD showWithStatus:JMLocalized(@"Connection Testing...")];
                                                       // 保存连接
                                                       [SINGLETONBLE connectWithPeripheral:peripheral
                                                                                formRecovery:YES
                                                                                  complete:complete];
                                                   }];
    // 非防丢单
    UIAlertAction *lose = [UIAlertAction actionWithTitle:JMLocalized(@"Non Form Recovery connection test")
                                                   style:UIAlertActionStyleDefault
                                                 handler:^(UIAlertAction * _Nonnull action) {
                                                     [SVProgressHUD showWithStatus:JMLocalized(@"Connection Testing...")];
                                                     [SINGLETONBLE connectWithPeripheral:peripheral
                                                                              formRecovery:NO
                                                                                complete:complete];
                                                 }];
    // 取消
    UIAlertAction *cancel = [UIAlertAction actionWithTitle:JMLocalized(@"Cancel")
                                                     style:UIAlertActionStyleDestructive
                                                   handler:^(UIAlertAction * _Nonnull action) {
                                                   }];
    [alert addAction:unLose];
    [alert addAction:lose];
    [alert addAction:cancel];
    [self.navigationController presentViewController:alert
                                            animated:YES
                                          completion:nil];
}
@end














